
*********
GooseHDF5
*********

.. note::

  This library is free to use under the `MIT license <https://github.com/tdegeus/GooseHDF5/blob/master/LICENSE>`_. Any additions are very much appreciated, in terms of suggested functionality, code, documentation, testimonials, word of mouth advertisement, etc. Bug reports or feature requests can be filed on `GitHub <http://github.com/tdegeus/GooseHDF5>`_. As always, the code comes with no guarantee. None of the developers can be held responsible for possible mistakes.

  Download: `.zip file <https://github.com/tdegeus/GooseHDF5/zipball/master>`_ | `.tar.gz file <https://github.com/tdegeus/GooseHDF5/tarball/master>`_.

  (c - `MIT <https://github.com/tdegeus/GooseHDF5/blob/master/LICENSE>`_) T.W.J. de Geus (Tom) | tom@geus.me | `www.geus.me <http://www.geus.me>`_ | `github.com/tdegeus/GooseHDF5 <http://github.com/tdegeus/GooseHDF5>`_

Contents
========

.. toctree::
   :maxdepth: 1

   tools.rst
   module.rst
   examples.rst

Getting GooseHDF5
=================

Using conda
-----------

.. code-block:: none

  conda install -c conda-forge goosehdf5

Using PyPi
----------

.. code-block:: none

  python -m pip install GooseHDF5

From source
-----------

.. code-block:: none

  git checkout https://github.com/tdegeus/GooseHDF5.git
  cd GooseHDF5

  python -m pip install .
